.. include:: ../README.rst

Table of Contents
=================

.. toctree::
    :maxdepth: 4
    :hidden:

    self

.. toctree::
    :caption: Examples

    examples

.. toctree::
    :caption: API Reference
    :maxdepth: 3

    api

.. toctree::
    :caption: Tutorials

    LSM6DSOX and ISM330DHC 6 DoF IMU Guide <https://learn.adafruit.com/lsm6dsox-and-ism330dhc-6-dof-imu/python-circuitpython>
    Adafruit LSM6DS33 6-DoF IMU Breakout Guide <https://learn.adafruit.com/lsm6ds33-6-dof-imu=accelerometer-gyro/python-circuitpython>
    ST 9-DoF Combo Breakouts and Wings Guide <https://learn.adafruit.com/st-9-dof-combo/python-circuitpython>

.. toctree::
    :caption: Related Products

    * Adafruit LSM6DSOX Breakout <https://www.adafruit.com/products/4438>

    * Adafruit ISM330DHCX Breakout <https://www.adafruit.com/product/4502>

    * Adafruit LSM6DSO32  Breakout <https://www.adafruit.com/product/4692>

    * Adafruit LSM6DS33 Breakout <https://www.adafruit.com/product/4480>

    * Adafruit ISM330DHCX + LIS3MDL FEATHERWING <https://www.adafruit.com/product/4569>

    * Adafruit LSM6DSOX + LIS3MDL - 9 DOF IMU Breakout <https://www.adafruit.com/product/4517>

    * Adafruit LSM6DS33 + LIS3MDL - 9 DOF IMU Breakout <https://www.adafruit.com/product/4485>

    * Adafruit LSM6DSOX + LIS3MDL  9 DOF IMU FeatherWing <https://www.adafruit.com/product/4565>


.. toctree::
    :caption: Other Links

    Download from GitHub <https://github.com/adafruit/Adafruit_CircuitPython_LSM6DS/releases/latest>
    Download Library Bundle <https://circuitpython.org/libraries>
    CircuitPython Reference Documentation <https://docs.circuitpython.org>
    CircuitPython Support Forum <https://forums.adafruit.com/viewforum.php?f=60>
    Discord Chat <https://adafru.it/discord>
    Adafruit Learning System <https://learn.adafruit.com>
    Adafruit Blog <https://blog.adafruit.com>
    Adafruit Store <https://www.adafruit.com>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
